@@ -11,6 +11,7 @@ from flask_autoapi.endpoint import BaseEndpoint, BaseListEndpoint
 
 
 class AutoAPI(object):
+
     def __init__(self):
         self.api = Api()
         self.app = None
@@ -19,7 +20,7 @@ class AutoAPI(object):
         self.doc_folder = "docs"
         self._lazy_resources = []
         self._custom_resources = {}
-    
+
     def init_app(self, app, model_list, decorator_list=None, project_name=""):
         if not isinstance(model_list, (list, tuple)):
             raise Exception("model_list 应该是一个列表，不是{}".format(type(model_list)))
@@ -28,17 +29,18 @@ class AutoAPI(object):
                 raise Exception("model 应该继承自 ApiModel")
         self.app = app
         self.model_list = model_list
-        self.project_name = project_name if project_name else os.getcwd().split("/")[-1]
+        self.project_name = project_name if project_name else os.getcwd(
+        ).split("/")[-1]
         if not self.project_name:
             raise Exception("project_name 不能为空，需要使用 project_name 作为 URL 前缀")
-        self.app.add_url_rule("/docs/", "docs", self._static_file, strict_slashes=False)
-        self.app.add_url_rule("/docs/<path:path>", "docs", self._static_file, strict_slashes=False)
+        # self.app.add_url_rule("/docs/", "docs", self._static_file, strict_slashes=False)
+        # self.app.add_url_rule("/docs/<path:path>", "docs", self._static_file, strict_slashes=False)
         self._add_decorators(decorator_list)
         self._auto_urls()
         self.api.init_app(self.app)
         for data in self._lazy_resources:
             self.update_resource(data[0], *data[1:])
-    
+
     def update_resource(self, resource, *urls):
         self._custom_resources[resource.__name__] = urls[0]
         if self.app:
@@ -46,21 +48,27 @@ class AutoAPI(object):
             func = self.api.output(resource.as_view(endpoint))
             self._del_exists_endpoint(endpoint)
             for url in urls:
-                self.app.add_url_rule(url, endpoint, func, strict_slashes=False)
+                self.app.add_url_rule(url,
+                                      endpoint,
+                                      func,
+                                      strict_slashes=False)
         else:
             self._lazy_resources.append((resource, *urls))
-    
+
     def _del_exists_endpoint(self, endpoint):
         if self.app.view_functions.get(endpoint):
             del self.app.view_functions[endpoint]
-            self.app.url_map._rules = [rule for rule in self.app.url_map._rules if rule.endpoint != endpoint]
-    
+            self.app.url_map._rules = [
+                rule for rule in self.app.url_map._rules
+                if rule.endpoint != endpoint
+            ]
+
     def _static_file(self, path=None):
         if not path:
             path = "index.html"
         path = os.path.join(self.doc_folder, path)
         return self.app.send_static_file(path)
-    
+
     def _add_decorators(self, decorator_list):
         if decorator_list:
             BaseEndpoint.add_decorators(decorator_list)
@@ -79,7 +87,8 @@ class AutoAPI(object):
             #         delattr(endpoint, method.lower())
             #         print("del method ", method)
             endpoint.decorators = copy(BaseEndpoint.decorators)
-            endpoint.method_decorators = deepcopy(BaseEndpoint.method_decorators)
+            endpoint.method_decorators = deepcopy(
+                BaseEndpoint.method_decorators)
             endpoint.add_decorators(model._meta.api_decorator_list)
             endpoint.add_method_decorators(model._meta.api_method_decorators)
             endpoints.append(endpoint)
@@ -88,19 +97,37 @@ class AutoAPI(object):
             endpoint = type(class_name, (BaseListEndpoint, ), {})
             endpoint.Model = model
             endpoint.decorators = copy(BaseListEndpoint.decorators)
-            endpoint.method_decorators = deepcopy(BaseListEndpoint.method_decorators)
+            endpoint.method_decorators = deepcopy(
+                BaseListEndpoint.method_decorators)
             endpoint.add_decorators(model._meta.list_api_decorator_list)
-            endpoint.add_method_decorators(model._meta.list_api_method_decorators)
+            endpoint.add_method_decorators(
+                model._meta.list_api_method_decorators)
             endpoints.append(endpoint)
-        
+
         for endpoint in endpoints:
             if endpoint.Type:
-                url = "/".join(["", self.project_name.lower(), endpoint.Model.__name__.lower(), endpoint.Type.lower(), ""])
-                self.api.add_resource(endpoint, url, endpoint=endpoint.__name__.lower(), strict_slashes=False)
+                url = "/".join([
+                    "",
+                    self.project_name.lower(),
+                    endpoint.Model.__name__.lower(),
+                    endpoint.Type.lower(), ""
+                ])
+                self.api.add_resource(endpoint,
+                                      url,
+                                      endpoint=endpoint.__name__.lower(),
+                                      strict_slashes=False)
             else:
-                url1 = "/".join(["", self.project_name.lower(), endpoint.Model.__name__.lower(), ""])
+                url1 = "/".join([
+                    "",
+                    self.project_name.lower(),
+                    endpoint.Model.__name__.lower(), ""
+                ])
                 url2 = url1 + "<key>/"
-                self.api.add_resource(endpoint, url1, url2, endpoint=endpoint.__name__.lower(), strict_slashes=False)
+                self.api.add_resource(endpoint,
+                                      url1,
+                                      url2,
+                                      endpoint=endpoint.__name__.lower(),
+                                      strict_slashes=False)
 
 
 def param_extrator(param_class):
@@ -108,6 +135,7 @@ def param_extrator(param_class):
         raise TypeError("param_class should be subclass of Param")
 
     def wrapper(func):
+
         @wraps(func)
         def wrapper2(*args, **kwargs):
             if request.content_type == "application/json":
@@ -121,4 +149,4 @@ def param_extrator(param_class):
 
         return wrapper2
 
-    return wrapper
\ No newline at end of file
+    return wrapper
